# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.0] - Speech
### Added
- Speech module

[0.1.0]: https://bitbucket.org/bkvaluemeal/myai/issues/1/speech
